# -*- coding: utf-8 -*-
from setuphelpers import *


bin_name_string = "Wireshark-win32-%s.exe"


def update_package():
    print("Download/Update package content from upstream binary sources")

    from waptpackage import PackageEntry
    import requests

    # Update transition from BeautifulSoup 3 to 4
    try:
        import bs4 as BeautifulSoup
    except:
        import BeautifulSoup

    # Getting proxy informations from WAPT settings
    proxy = {}
    if isfile(makepath(application_data(), "waptconsole", "waptconsole.ini")):
        proxywapt = inifile_readstring(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini"), "global", "http_proxy")
        if proxywapt:
            proxy = {"http": proxywapt, "https": proxywapt}

    # Specific app values
    app_name = control.name
    url = control.sources

    # Getting latest version from official website
    page = requests.get(url, headers={"User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64)"}, proxies=proxy).text
    bs = BeautifulSoup.BeautifulSoup(page)
    # bs = BeautifulSoup.BeautifulSoup(page,features="html.parser") # For bs4 only
    bs_raw_string = bs.find("a", {"class": "accordion-toggle"}).text
    version = (bs_raw_string.split(")")[0]).split("(")[1]

    latest_bin = bin_name_string % version
    url_dl = "https://1.eu.dl.wireshark.org/win32/" + latest_bin

    print("Latest " + app_name + " version is: " + version)
    print("Download url is: " + url_dl)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: " + latest_bin)
        wget(url_dl, latest_bin, proxies=proxy)

        # Change version of the package
        pe = PackageEntry().load_control_from_wapt(".")
        pe.version = "%s-%s" % (version, int(pe.version.split("-", 1)[1]) + 1)
        pe.save_control_to_wapt(".")
        print("Changing version to " + pe.version + " in WAPT\\control")
        print("Update package done. You can now build-upload your package")
    else:
        print("This package is already up-to-date")

    # Deleting outdated binaries
    for bin_in_dir in glob.glob("*.exe") or glob.glob("*.msi"):
        if bin_in_dir != latest_bin:
            print("Outdated binary: " + bin_in_dir + " Deleted")
            remove_file(bin_in_dir)
